@@ -7,10 +7,16 @@
 # of the BSD license.  See the LICENSE file for details.
 
 import unittest
+
 import attotime
 
+
 class TestInitFunctions(unittest.TestCase):
     def test_import(self):
-        self.assertEqual(attotime.attodatetime, attotime.objects.attodatetime.attodatetime)
+        self.assertEqual(
+            attotime.attodatetime, attotime.objects.attodatetime.attodatetime
+        )
         self.assertEqual(attotime.attotime, attotime.objects.attotime.attotime)
-        self.assertEqual(attotime.attotimedelta, attotime.objects.attotimedelta.attotimedelta)
+        self.assertEqual(
+            attotime.attotimedelta, attotime.objects.attotimedelta.attotimedelta
+        )
